summaryrefslogtreecommitdiff
path: root/libavcodec/h261dec.c
diff options
context:
space:
mode:
authorStefano Sabatini <stefano.sabatini-lala@poste.it>2011-04-29 18:53:57 +0200
committerDiego Biurrun <diego@biurrun.de>2011-05-02 12:18:44 +0200
commit975a1447f76e8d30fc01e6ea5466c84faf3d76e4 (patch)
treed462ee5cc7a2f59c44f797c97fc237c999c94e55 /libavcodec/h261dec.c
parent6209669de4a0aa056ae05b0a2c78eaf2ca489b23 (diff)
Replace deprecated FF_*_TYPE symbols with AV_PICTURE_TYPE_*.
Signed-off-by: Diego Biurrun <diego@biurrun.de>
Diffstat (limited to 'libavcodec/h261dec.c')
-rw-r--r--libavcodec/h261dec.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libavcodec/h261dec.c b/libavcodec/h261dec.c
index a5ede3e691..a335d68ff1 100644
--- a/libavcodec/h261dec.c
+++ b/libavcodec/h261dec.c
@@ -497,9 +497,9 @@ static int h261_decode_picture_header(H261Context *h){
skip_bits(&s->gb, 8);
}
// h261 has no I-FRAMES, but if we pass FF_I_TYPE for the first frame, the codec crashes if it does
// not contain all I-blocks (e.g. when a packet is lost)
- s->pict_type = FF_P_TYPE;
+ s->pict_type = AV_PICTURE_TYPE_P;
h->gob_number = 0;
return 0;
@@ -597,10 +597,10 @@ retry:
// for skipping the frame
s->current_picture.pict_type= s->pict_type;
- s->current_picture.key_frame= s->pict_type == FF_I_TYPE;
+ s->current_picture.key_frame= s->pict_type == AV_PICTURE_TYPE_I;
- if( (avctx->skip_frame >= AVDISCARD_NONREF && s->pict_type==FF_B_TYPE)
- ||(avctx->skip_frame >= AVDISCARD_NONKEY && s->pict_type!=FF_I_TYPE)
+ if( (avctx->skip_frame >= AVDISCARD_NONREF && s->pict_type==AV_PICTURE_TYPE_B)
+ ||(avctx->skip_frame >= AVDISCARD_NONKEY && s->pict_type!=AV_PICTURE_TYPE_I)
|| avctx->skip_frame >= AVDISCARD_ALL)
return get_consumed_bytes(s, buf_size);
@@ -497,9 +497,9 @@ static int h261_decode_picture_header(H261Context *h){
skip_bits(&s->gb, 8);
}
- // h261 has no I-FRAMES, but if we pass FF_I_TYPE for the first frame, the codec crashes if it does
+ // h261 has no I-FRAMES, but if we pass AV_PICTURE_TYPE_I for the first frame, the codec crashes if it does
// not contain all I-blocks (e.g. when a packet is lost)